==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframedatavariablelist.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A decorator for the ComboBox or RadioBox which contains data variables
//

#ifndef IGGFRAMEDATAVARIABLELIST_H
#define IGGFRAMEDATAVARIABLELIST_H


#include "iggframe.h"


class iObjectKey;

class iggDataTypeProvider;
class iggWidgetTextArea;
class iggWidgetKeyItemizedSelectionBox;


class iggFrameDataVariableList : public iggFrame
{

public:

	iggFrameDataVariableList(const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);

	//
	//  Decorator functions
	//
	virtual void InsertItem(const iString &text);
	virtual void Complete(int extraoffset = 0);
	void SetIndex(int i);

protected:

	void UpdateList();

	virtual void UpdateChildren();

	iggWidget *mWidgetCombo, *mWidgetRadio;
	iggWidgetKeyItemizedSelectionBox *mBoxCombo, *mBoxRadio;
	int mOffset;
	const iObjectKey &mKey, *mActivationKey;
	bool mCompleted;
	const iggDataTypeProvider *mProvider;
};

#endif  // IGGFRAMEDATAVARIABLELIST_H

==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/shells/generic/iggframedatavariablelist.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A decorator for the ComboBox or RadioBox which contains data variables
//

#ifndef IGGFRAMEDATAVARIABLELIST_H
#define IGGFRAMEDATAVARIABLELIST_H


#include "iggframe.h"


class iDataInfo;
class iObjectKey;

class iggDataTypeProvider;
class iggWidgetTextArea;
class iggWidgetKeyItemizedSelectionBox;


class iggFrameDataVariableList : public iggFrame
{

public:

	iggFrameDataVariableList(const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
	iggFrameDataVariableList(const iDataInfo &info, const iggDataTypeProvider *provider, const iString &title, const iObjectKey &key, const iObjectKey *actkey, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);

	//
	//  Decorator functions
	//
	virtual void InsertItem(const iString &text);
	virtual void Complete(int extraoffset = 0);
	void SetIndex(int i);

protected:

	void UpdateList();
	virtual void UpdateChildren();

	void Define(const iggDataTypeProvider *provider);

	iggWidget *mWidgetCombo, *mWidgetRadio;
	iggWidgetKeyItemizedSelectionBox *mBoxCombo, *mBoxRadio;
	int mOffset;
	const iObjectKey &mKey, *mActivationKey;
	bool mCompleted;
	const iggDataTypeProvider *mProvider;
};

#endif  // IGGFRAMEDATAVARIABLELIST_H
